@@ -15,8 +15,8 @@ with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
 # This call to setup() does all the work
 setup(
     name="testcsg",
-    version="0.1.5",
-    description="Test CSG library",
+    version="0.1.7",
+    description="API for interacting with the Computer Systems Genome database.",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://csgenome.org/",
@@ -38,4 +38,4 @@ setup(
     py_modules=["clientAPI.base", "clientAPI.client", "clientAPI.mixin", "clientAPI.utils"],
     include_package_data=True,
     install_requires=["flask", "requests"]
-)
\ No newline at end of file
+)
